function u_lp=tri_var_ss(u,t,trihlfwid,minpct,maxgaplen,tout);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% updates tri_var to implement subsampling (and hence run much faster)
%       d.c. nov 2010
% inputs:
% 
% t = vector of times in days, can be non-uniformly spaced and gappy
% u = corresponding velocities
% trihlfwid = triangle halfwidth in hours
%       (tri.m implements trihlfwid = 25)
% minpct = percentage of good points under triangle w/r/t 
%   total number expected for no gaps using nominal dt
%              (reasonable default is 25)
% maxgaplen = max allowable gap length (fraction of trihlfwid) under triangle
%               (reasonable default is 1.4) 
% tout = times at which output will be given
% 
% outputs:
% % u_lp = the (same-sized) lowpass output vector with
%       nans at start/end due to halfwidth of triangle, and
%       nans where thresholds are not met

% caution: mode(diff(t)) is used as the nominal time interval to set 
%   quality control limits

%%%

modn = 1000;

% nominal data time spacing (hrs)
nomdt = mode(diff(t))*24;

% initialize output
u_lp = nan*ones(size(tout));

for i = 1:length(tout)
    % get values that fall under triangle
    whr = find(~isnan(u) & ~isnan(t) & ...
        t > tout(i) - trihlfwid/24 & t < tout(i) + trihlfwid/24);
    if 100*length(whr)/(2*trihlfwid/nomdt) > minpct & ...
            24*max(diff(t(whr))) < maxgaplen*trihlfwid
        %determine weighting
        for j = 1:length(whr)
            wts(j) = 1 - (24*abs( t(whr(j)) - tout(i) ) / trihlfwid);
        end
        wts = reshape(wts,size(u(whr)));
        u_lp(i) = sum(wts.*u(whr))/sum(wts);
        clear wts;
    end
    if ~mod(i-1,modn)
        fprintf('tri_var_ss: point %d of %d\n',i,length(tout));
    end
end

